from importlib import resources

from stimulsoft_reports.classes.StiFileResult import StiFileResult
from stimulsoft_data_adapters.enums.StiDataType import StiDataType


class StiScriptResource:

    def getResult(name: str) -> StiFileResult:
        try:
            data = resources.read_binary(__package__, name)
        except Exception as e:
            message = str(e)
            return StiFileResult.getError(message)
        
        return StiFileResult(data, StiDataType.JAVASCRIPT)


from ..export.enums import StiDashboardExportFormat, StiDashboardScaleMode
from .StiDashboardExportSettings import StiDashboardExportSettings


class StiExcelDashboardExportSettings(StiDashboardExportSettings):

### Properties

    scaleMode: StiDashboardScaleMode = StiDashboardScaleMode.VIEW_SIZE
    """[enum] Specifies the scaling mode of the dashboard content."""

    imageQuality: int = 200
    """The image quality of images which will be exported to a result file."""

    exportDataOnly: bool = False
    """Specifies that only data will be exported."""


### Helpers

    def getExportFormat(self):
        return StiDashboardExportFormat.EXCEL


from stimulsoft_reports.export.StiExportSettings import StiExportSettings


class StiDashboardExportSettings(StiExportSettings):

### Properties

    renderBorders: bool = True
    """Enables or disables rendering of the defined element borders."""

    renderSingleElement: bool = False
    """Enables or disables exporting a single dashboard element to the entire page."""

    renderSinglePage: bool = False
    """Enables or disables exporting only the first page if elements require multiple pages to be rendered."""

    applyDefaultFilters: bool = False
    """Applies default filters to dashboard elements."""



from setuptools import setup, find_packages

with open('README.md') as file:
    readmeFile = file.read()

setup(
    name = 'stimulsoft_dashboards',
    version = '2025.3.1',
    author = 'Stimulsoft',
    author_email = 'info@stimulsoft.com',
    description = 'Data visualization in Python applications.',
    long_description = readmeFile,
    long_description_content_type = 'text/markdown',
    url = 'https://www.stimulsoft.com/en/products/dashboards-python',
    license = 'https://www.stimulsoft.com/en/licensing/developers',
    classifiers=[
        'License :: Other/Proprietary License',
        'Framework :: Django',
        'Framework :: Flask',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Topic :: Office/Business',
        'Topic :: Software Development'
    ],
    install_requires = ['stimulsoft-reports==2025.3.1'],
    extras_require = {'ext': 'stimulsoft-reports[ext]==2025.3.1'},
    packages = find_packages(include=['stimulsoft_dashboards', 'stimulsoft_dashboards.*']),
    package_data = {'stimulsoft_dashboards': ['**/scripts/*.js']},
    python_requires = '>=3.10'
)



from stimulsoft_reports.enums import PaperKind
from stimulsoft_reports.report.enums import StiPageOrientation

from ..export.enums import StiDashboardExportFormat, StiDashboardScaleMode
from .StiDashboardExportSettings import StiDashboardExportSettings


class StiPdfDashboardExportSettings(StiDashboardExportSettings):

### Properties

    scaleMode: StiDashboardScaleMode = StiDashboardScaleMode.VIEW_SIZE
    """[enum] Specifies the scaling mode of the dashboard content."""

    autoPrint = False
    """Indicates that an exported document will start printing after opening."""

    imageQuality: int = 200
    """The image quality of images which will be exported to a result file."""

    paperSize: PaperKind = PaperKind.A4
    """[enum] The page size of a resulting document."""

    orientation: StiPageOrientation = StiPageOrientation.LANDSCAPE
    """[enum] The page orientation of a resulting document."""


### Helpers

    def getExportFormat(self):
        return StiDashboardExportFormat.PDF
    